from inline_snapshot import external, register_format_alias, snapshot

register_format_alias(".html", ".txt")

workflow_show = snapshot(
    {
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", True),
            ("parameters_group_title_row", True),
        ): external("hash:5d0abaf6f1a0*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", False),
            ("parameters_group_title_row", True),
        ): external("hash:47004f712909*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", True),
            ("parameters_group_title_row", False),
        ): external("hash:d3695fdb7472*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", False),
            ("parameters_group_title_row", False),
        ): external("hash:db0c43c8233d*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", True),
            ("parameters_group_title_row", True),
        ): external("hash:ffc40bfdc5e9*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", False),
            ("parameters_group_title_row", True),
        ): external("hash:66a319534331*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", True),
            ("parameters_group_title_row", False),
        ): external("hash:0bed6d92c16c*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", False),
            ("parameters_group_title_row", False),
        ): external("hash:dbdc3c6e7683*.html"),
        (("show_description", True), ("description", ""), ("show_source", True)): external(
            "hash:361203a8fe16*.html"
        ),
        (
            ("show_description", True),
            ("description", "Custom heading"),
            ("show_source", True),
        ): external("hash:8476f864e849*.html"),
        (("show_description", False), ("description", ""), ("show_source", False)): external(
            "hash:78feb92e4171*.html"
        ),
        (
            ("show_heading", True),
            ("heading", ""),
            ("heading_level", 1),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:f90542b4e3cb*.html"),
        (
            ("show_heading", True),
            ("heading", "Custom heading"),
            ("heading_level", 2),
            ("show_toc_entry", False),
            ("toc_label", "Custom toc label"),
        ): external("hash:ac47b3b93370*.html"),
        (
            ("show_heading", False),
            ("heading", ""),
            ("heading_level", 3),
            ("show_toc_entry", True),
            ("toc_label", ""),
        ): external("hash:1322d6390dbc*.html"),
        (
            ("show_signature", True),
            ("signature_version", "major"),
            ("signature_version_string", ""),
            ("signature_show_secrets", True),
            ("signature_show_permissions", True),
        ): external("hash:6d20fba34c55*.html"),
        (
            ("show_signature", True),
            ("signature_version", "semver"),
            ("signature_version_string", ""),
            ("signature_show_secrets", True),
            ("signature_show_permissions", False),
        ): external("hash:06f909d26ca3*.html"),
        (
            ("show_signature", True),
            ("signature_version", "string"),
            ("signature_version_string", "latest"),
            ("signature_show_secrets", False),
            ("signature_show_permissions", True),
        ): external("hash:23cc1367f9dd*.html"),
        (
            ("show_signature", False),
            ("signature_version", "string"),
            ("signature_version_string", ""),
            ("signature_show_secrets", False),
            ("signature_show_permissions", False),
        ): external("hash:2500c66e1646*.html"),
        (
            ("identifier", ".github/workflows/reusable-workflow.yml"),
            ("show_signature", True),
            ("signature_show_permissions", True),
        ): external("hash:b6163f7b64f0*.html"),
        (
            ("identifier", ".github/workflows/read-write-workflow.yml"),
            ("show_signature", True),
            ("signature_show_permissions", True),
        ): external("hash:9cc6f18114bf*.html"),
        (
            ("identifier", ".github/workflows/write-all-workflow.yml"),
            ("show_signature", True),
            ("signature_show_permissions", True),
        ): external("hash:8bacb89d7527*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:6af63bf65a64*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:699c6bcc6322*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:50af14995537*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:24b2b02efe6e*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:62bff06eac18*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:757b79d7975f*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:ecf772312e7e*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:d0d656ae3243*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:93bf082d40ca*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("show_secrets", True),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:27af0061b435*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:bbea0ecf08ae*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("show_secrets", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:22929d6c2b70*.html"),
    }
)

action_show = snapshot(
    {
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", True),
            ("parameters_group_title_row", True),
        ): external("hash:8b65d193fe31*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", False),
            ("parameters_group_title_row", True),
        ): external("hash:43ad574e6f4b*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", True),
            ("parameters_group_title_row", False),
        ): external("hash:a34a87167e37*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "table"),
            ("parameters_groups", False),
            ("parameters_group_title_row", False),
        ): external("hash:81baa4bca07b*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", True),
            ("parameters_group_title_row", True),
        ): external("hash:ebb0bfe46e02*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", False),
            ("parameters_group_title_row", True),
        ): external("hash:5e3b7eb70931*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", True),
            ("parameters_group_title_row", False),
        ): external("hash:0de8e0706404*.html"),
        (
            ("show_inputs", True),
            ("show_outputs", True),
            ("parameters_section_style", "list"),
            ("parameters_groups", False),
            ("parameters_group_title_row", False),
        ): external("hash:72b55cb37adc*.html"),
        (("show_description", True), ("description", ""), ("show_source", True)): external(
            "hash:7a54a2a8729f*.html"
        ),
        (
            ("show_description", True),
            ("description", "Custom heading"),
            ("show_source", True),
        ): external("hash:1f92a9273ccc*.html"),
        (("show_description", False), ("description", ""), ("show_source", False)): external(
            "hash:5a2f11e94bc0*.html"
        ),
        (
            ("show_heading", True),
            ("heading", ""),
            ("heading_level", 1),
            ("show_branding", False),
            ("branding_icon", ""),
            ("branding_icon_color", ""),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:2eb63f18b2d0*.html"),
        (
            ("show_heading", True),
            ("heading", "Custom heading"),
            ("heading_level", 2),
            ("show_branding", False),
            ("branding_icon", ""),
            ("branding_icon_color", ""),
            ("show_toc_entry", False),
            ("toc_label", "Custom toc label"),
        ): external("hash:856a4ff20ee1*.html"),
        (
            ("show_heading", True),
            ("heading", ""),
            ("heading_level", 1),
            ("show_branding", True),
            ("branding_icon", ""),
            ("branding_icon_color", ""),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:0a37a4286738*.html"),
        (
            ("show_heading", True),
            ("heading", ""),
            ("heading_level", 2),
            ("show_branding", True),
            ("branding_icon", "green"),
            ("branding_icon_color", ""),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:3cb099624d88*.html"),
        (
            ("show_heading", True),
            ("heading", ""),
            ("heading_level", 3),
            ("show_branding", True),
            ("branding_icon", ""),
            ("branding_icon_color", "github"),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:c50b7f91aaff*.html"),
        (
            ("show_heading", False),
            ("heading", ""),
            ("heading_level", 1),
            ("show_branding", False),
            ("branding_icon", ""),
            ("branding_icon_color", ""),
            ("show_toc_entry", True),
            ("toc_label", ""),
        ): external("hash:c8c895c400f0*.html"),
        (
            ("show_heading", False),
            ("heading", ""),
            ("heading_level", 1),
            ("show_branding", False),
            ("branding_icon", ""),
            ("branding_icon_color", ""),
            ("show_toc_entry", False),
            ("toc_label", ""),
        ): external("hash:36d559797138*.html"),
        (
            ("show_signature", True),
            ("signature_version", "major"),
            ("signature_version_string", ""),
        ): external("hash:94b8c0c6610d*.html"),
        (
            ("show_signature", True),
            ("signature_version", "semver"),
            ("signature_version_string", ""),
        ): external("hash:ace14d7e4e53*.html"),
        (
            ("show_signature", True),
            ("signature_version", "string"),
            ("signature_version_string", "latest"),
        ): external("hash:e567efbdae19*.html"),
        (
            ("show_signature", False),
            ("signature_version", "string"),
            ("signature_version_string", ""),
        ): external("hash:98e4b6474a6f*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:6962c89022a7*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:1efa0765882b*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "table"),
        ): external("hash:c2181f9e06dd*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:e728a1168528*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:8bedbe96ebb5*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "table"),
        ): external("hash:b972a05ffc56*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:a683a1d590ea*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:5508680ad196*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("parameters_order", "alphabetical"),
            ("parameters_section_style", "list"),
        ): external("hash:28df0ab9fe56*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", False),
            ("show_outputs", True),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:0d0e2427b85f*.html"),
        (
            ("show_inputs", True),
            ("show_inputs_only_required", True),
            ("show_outputs", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:074e6b0350e6*.html"),
        (
            ("show_inputs", False),
            ("show_inputs_only_required", False),
            ("show_outputs", False),
            ("parameters_order", "source"),
            ("parameters_section_style", "list"),
        ): external("hash:cdad9a8909ec*.html"),
    }
)
